Setup
======

Installation
-------------

The latest stable release or development release can be installed from PyPI.


**Pip**

Connect is on PyPi and can be installed using pip. The below will install the latest stable release
of the package.

::

   pip install credoai-connect

The latest development version can also be installed directly from github.

::

   pip install git+https://github.com/credo-ai/credoai_connect#develop   

If you are interested in contributing to the development of Connect and
would like to install requirements for testing and formatting, you'll
have to install the dev requirements.

::
   
   pip install credoai-connect[dev]

